Package 'rk.data.wrangling'

Title: A suite of plugins for modern data manipulation using 'dplyr'. Includes batch transformations, recoding multiple variables, and creating composite scores.
Description: A suite of plugins for modern data manipulation using 'dplyr'. Includes batch transformations, recoding multiple variables, and creating composite scores.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.1.3
Built: 2026-06-04 10:06:40 UTC
Source: https://github.com/AlfCano/rk.data.wrangling

Help Index